api.customernetworks.v1.test_helpers.network.search_customer_network — Argus-Toolbelt 1.0 documentation

# Source code for api.customernetworks.v1.test_helpers.network.search_customer_network

    def success(function):
        """Mock https://portal.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 200"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "POST",
                    r"https://portal.mnemonic.no/web/api/customernetworks/v1/network/search",
                    status_code=200,
                    json=fake_response({'offset': {'type': 'int', 'name': 'offset'}, 'limit': {'type': 'int', 'name': 'limit'}, 'responseCode': {'type': 'int', 'name': 'responseCode'}, 'count': {'type': 'int', 'name': 'count'}, 'data': {'type': 'list', 'items': {'id': {'type': 'int'}, 'customer': {'id': {'type': 'int'}, 'name': {'type': 'str'}, 'shortName': {'type': 'str'}, 'domain': {'$ref': '#/definitions/DomainInfo'}}, 'location': {'id': {'type': 'int'}, 'shortName': {'type': 'str'}, 'name': {'type': 'str'}, 'timeZone': {'type': 'str'}}, 'description': {'type': 'str', 'position': 0, 'description': 'Description of the customer network '}, 'networkAddress': {'maskBits': {'type': 'int'}, 'host': {'type': 'bool', 'xml': {'attribute': True}, 'readOnly': True, 'default': False}, 'ipv6': {'type': 'bool', 'xml': {'attribute': True}, 'readOnly': True, 'default': False}, 'multicast': {'type': 'bool', 'default': False}, 'public': {'type': 'bool', 'default': False}, 'address': {'type': 'str', 'xml': {'attribute': True}, 'readOnly': True}}, 'lastUpdatedByUser': {'id': {'type': 'int'}, 'customerID': {'type': 'int'}, 'domain': {'$ref': '#/definitions/DomainInfo'}, 'userName': {'type': 'str'}, 'name': {'type': 'str'}, 'type': 'str', 'options': ['user', 'group']}, 'lastUpdatedTimestamp': {'type': 'int', 'position': 0, 'description': 'Timestamp of last update of the customer network '}, 'createdByUser': {'id': {'type': 'int'}, 'customerID': {'type': 'int'}, 'domain': {'$ref': '#/definitions/DomainInfo'}, 'userName': {'type': 'str'}, 'name': {'type': 'str'}, 'type': 'str', 'options': ['user', 'group']}, 'createdTimestamp': {'type': 'int', 'position': 0, 'description': 'Timestamp of creation of the customer network '}, 'zone': {'type': 'str', 'enum': ['INTERNAL', 'EXTERNAL', 'DMZ', 'UNKNOWN']}, 'flags': {'type': 'list', 'position': 0, 'description': 'Flags assigned to the object. ', 'uniqueItems': True, 'items': {'type': 'str', 'enum': ['AUTO', 'NAT', 'PROXY', 'SCANNER', 'CLIENT', 'SERVER', 'DNS', 'GUEST', 'UNASSIGNED', 'DELETED']}}}, 'name': 'data'}, 'metaData': {'type': 'dict', 'additionalProperties': {'type': 'dict'}, 'name': 'metaData'}, 'messages': {'type': 'list', 'items': {'message': {'type': 'str'}, 'messageTemplate': {'type': 'str'}, 'type': 'str', 'field': {'type': 'str'}, 'parameter': {'type': 'dict'}, 'timestamp': {'type': 'int'}, 'options': ['FIELD_ERROR', 'ACTION_ERROR', 'WARNING', 'NOTIFICATION', 'INFO']}, 'name': 'messages'}, 'currentPage': {'type': 'int', 'name': 'currentPage'}, 'size': {'type': 'int', 'name': 'size'}})
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator

    def unauthorized(function):
        """Mock https://portal.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 401"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "POST",
                    r"https://portal.mnemonic.no/web/api/customernetworks/v1/network/search",
                    status_code=401,
                    json=None
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator

    def forbidden(function):
        """Mock https://portal.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 403"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "POST",
                    r"https://portal.mnemonic.no/web/api/customernetworks/v1/network/search",
                    status_code=403,
                    json=None
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator

    def not_found(function):
        """Mock https://portal.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 404"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "POST",
                    r"https://portal.mnemonic.no/web/api/customernetworks/v1/network/search",
                    status_code=404,
                    json=None
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator